/* eslint-disable react/prop-types */
import { useContext } from "react";
import { CartContext } from "../cartContext";
import { starIcon } from "../../assets/SvgIcons/svgIcons";

const ProductCard = ({ product }) => {
  const { addToCart } = useContext(CartContext);

  const textColorClass =
    product?.rating?.count > 300 ? "text-green-500" : "text-red-500";

  return (
    <div className="max-w-xs rounded-lg border border-gray-200 bg-white shadow-md transform transition duration-700 hover:scale-105">
      <img
        src={product?.image}
        alt={product?.title}
        className="w-full h-48 object-fill rounded-t-lg mt-4 p-4"
      />
      <div className="p-4">
        <h5 className="text-sm font-semibold text-gray-800 line-clamp-1">
          {product?.title}
        </h5>
        <p className="text-gray-600 text-justify line-clamp-3 text-xs">
          {product?.description}
        </p>
        <p className="mt-2 text-sm font-bold text-gray-900">
          ${product?.price}
        </p>
        <p className="mt-2 text-sm text-gray-900">
          Category: {product?.category}
        </p>
        <p className="mt-2 text-sm text-gray-900">
          <span className="flex gap-1">
            Ratings: <b>{product?.rating?.rate}</b>
            <p className="mt-0.5">{starIcon}</p>
          </span>{" "}
        </p>
        <p className="mt-2 text-sm text-gray-900">
          Only <b className={`${textColorClass}`}>{product?.rating?.count}</b>{" "}
          pieces left
        </p>
        <button
          onClick={() => addToCart(product)}
          className="flex px-4 py-2 items-center bg-gray-800 text-white text-xs font-bold uppercase rounded hover:bg-gray-700 focus:outline-none focus:bg-gray-700 mt-4"
        >
          Add to cart
        </button>
      </div>
    </div>
  );
};

export default ProductCard;
