/* eslint-disable react/prop-types */
/* eslint-disable react-refresh/only-export-components */
import { createContext, useState, useEffect } from "react";

export const CartContext = createContext();

export const CartProvider = ({ children }) => {
  const [cartItems, setCartItems] = useState(
    localStorage?.getItem("cartItems")
      ? JSON?.parse(localStorage?.getItem("cartItems"))
      : []
  );

  const addToCart = (item) => {
    const isItemInCart = cartItems?.find(
      (cartItem) => cartItem?.id === item?.id
    );

    if (isItemInCart) {
      setCartItems(
        cartItems?.map((cartItem) =>
          cartItem?.id === item?.id
            ? { ...cartItem, quantity: cartItem?.quantity + 1 }
            : cartItem
        )
      );
    } else {
      setCartItems([...cartItems, { ...item, quantity: 1 }]);
    }
  };

  const removeFromCart = (item) => {
    const isItemInCart = cartItems?.find(
      (cartItem) => cartItem?.id === item?.id
    );

    if (isItemInCart?.quantity === 1) {
      setCartItems(cartItems?.filter((cartItem) => cartItem?.id !== item?.id));
    } else {
      setCartItems(
        cartItems?.map((cartItem) =>
          cartItem?.id === item?.id
            ? { ...cartItem, quantity: cartItem?.quantity - 1 }
            : cartItem
        )
      );
    }
  };

  const removeItem = (item) => {
    setCartItems(cartItems?.filter((cartItem) => cartItem?.id !== item?.id));
  };

  const clearCart = () => {
    setCartItems([]);
  };

  const getCartTotal = () => {
    const total = cartItems?.reduce(
      (sum, item) => sum + item?.price * item?.quantity,
      0
    );
    return total?.toFixed(2);
  };

  useEffect(() => {
    localStorage?.setItem("cartItems", JSON?.stringify(cartItems));
  }, [cartItems]);

  useEffect(() => {
    const cartItems = localStorage?.getItem("cartItems");
    if (cartItems) {
      setCartItems(JSON?.parse(cartItems));
    }
  }, []);

  return (
    <CartContext.Provider
      value={{
        cartItems,
        addToCart,
        removeFromCart,
        removeItem,
        clearCart,
        getCartTotal,
      }}
    >
      {children}
    </CartContext.Provider>
  );
};
