/* eslint-disable no-unsafe-optional-chaining */
/* eslint-disable react-hooks/rules-of-hooks */
import { useState, useEffect } from "react";
import { fetchProducts } from "../api/api";

export const filterOperations = () => {
  const [products, setProducts] = useState([]);
  const [filteredProducts, setFilteredProducts] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [filters, setFilters] = useState({
    category: "all",
    price: "all",
    rating: "all",
  });

  useEffect(() => {
    const getProducts = async () => {
      try {
        const data = await fetchProducts();
        setProducts(data);
        setFilteredProducts(data);
      } catch (err) {
        setError(err);
      } finally {
        setLoading(false);
      }
    };

    getProducts();
  }, []);

  useEffect(() => {
    const filterByCategory = (product) =>
      filters?.category === "all" || product?.category === filters?.category;

    const filterByPrice = (product) => {
      if (filters?.price === "all") return true;
      if (filters?.price === "low") return product?.price < 50;
      if (filters?.price === "mid")
        return product?.price >= 50 && product?.price <= 100;
      if (filters?.price === "high") return product?.price > 100;
    };

    const filterByRating = (product) =>
      filters?.rating === "all" ||
      product?.rating?.rate >= parseFloat(filters?.rating);

    const filtered = products?.filter(
      (product) =>
        filterByCategory(product) &&
        filterByPrice(product) &&
        filterByRating(product)
    );

    setFilteredProducts(filtered);
  }, [filters, products]);

  const handleFilterChange = (e) => {
    const { name, value } = e?.target;
    setFilters((prev) => ({ ...prev, [name]: value }));
  };

  return {
    products,
    filteredProducts,
    loading,
    error,
    filters,
    handleFilterChange,
  };
};
